@@ -128,9 +128,11 @@ class OSDIService:
         if response.get("total_pages") == 0:
             return []
         all_res = response["_embedded"][full_obj_name]
-        while len(response["_embedded"][full_obj_name]) >= response["per_page"] and len(
-            all_res
-        ) < response.get("total_records", math.inf):
+        while (
+            len(response["_embedded"][full_obj_name]) >= response["per_page"]
+            and len(all_res) < response.get("total_records", math.inf)
+            and "next" in response["_links"]
+        ):
             if len(all_res) % 1000 == 0:
                 self.logger.info(f"Retrieved {len(all_res)} {object_type}, still retrieving...")
             url = response["_links"]["next"]["href"]
